@@ -10,14 +10,14 @@ Gnumeric
 </name>
 
 <description>  
-lightweight spreadsheet
+Lightweight spreadsheet
 </description>
 
 <installable>
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/000/200/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
