@@ -10,7 +10,7 @@ Shotwell
 </name>
 
 <description>  
-digital photo organizer
+Digital photo organizer
 </description>
 
 <installable>
